========
Modules
========

regressors.stats
----------------

.. autofunction:: regressors.stats.sse
.. autofunction:: regressors.stats.adj_r2_score
.. autofunction:: regressors.stats.coef_se
.. autofunction:: regressors.stats.coef_tval
.. autofunction:: regressors.stats.coef_pval
.. autofunction:: regressors.stats.f_stat
.. autofunction:: regressors.stats.residuals
.. autofunction:: regressors.stats.summary

regressors.plots
----------------

.. autofunction:: regressors.plots.plot_residuals
.. autofunction:: regressors.plots.plot_qq
.. autofunction:: regressors.plots.plot_pca_pairs
.. autofunction:: regressors.plots.plot_scree

regressors.regressors
---------------------

.. autoclass:: regressors.regressors.PCR
   :members:

